@@ -1,7 +1,5 @@
 InternalSES.gee = function(target, reps, group, dataset, max_k = 3, threshold = 0.05, test = NULL, ini, wei = NULL, user_test = NULL, 
                                 hash = FALSE, varsize, stat_hash, pvalue_hash, targetID, correl, se, ncores) {
-  #get the current time
-  runtime = proc.time();
   #univariate feature selection test
   if ( is.null(ini) ) {
     univariateModels = univariateScore.gee(target, reps, group, dataset, test, wei = wei, targetID = targetID, correl = correl, se = se, ncores = ncores);
@@ -31,8 +29,6 @@ InternalSES.gee = function(target, reps, group, dataset, max_k = 3, threshold =
     results$univ = univariateModels;
     results$max_k = max_k;
     results$threshold = threshold;
-    runtime = proc.time() - runtime;
-    results$runtime = runtime;
     results$correl = correl
     results$se = se
     results$n.tests = length(stats)
@@ -127,8 +123,6 @@ InternalSES.gee = function(target, reps, group, dataset, max_k = 3, threshold =
   results$univ = univariateModels;
   results$max_k = max_k;
   results$threshold = threshold;
-  runtime = proc.time() - runtime;
-  results$runtime = runtime;
   results$correl = correl
   results$se = se
   results$n.tests = length(stats) + length( hashObject$stat_hash )
