@@ -41,7 +41,7 @@ fbed.glmm <- function(y, x, id, univ = NULL, alpha = 0.05, wei = NULL, K = 0, te
     n.tests <- 0
     stat <- univ$stat
     pval <- univ$pvalue
-    lik2 <- stat + lik1
+    lik2 <- 0.5 * stat + lik1
   }  
   s <- which(pval < sig)
   
