@@ -3,8 +3,8 @@ mmpc.path <- function(target, dataset, wei = NULL, max_ks = NULL, alphas = NULL
   if( is.null(alphas) )  alphas <- c(0.1, 0.05, 0.01)
   if( is.null(max_ks) )   max_ks <- c(4, 3, 2)  
   
-  alphas = sort(alphas, decreasing = TRUE)
-  max_ks = sort(max_ks, decreasing = TRUE)
+  alphas <- sort(alphas, decreasing = TRUE)
+  max_ks <- sort(max_ks, decreasing = TRUE)
   
   nalpha <- length(alphas);
   nmaxk <- length(max_ks);
@@ -13,16 +13,16 @@ mmpc.path <- function(target, dataset, wei = NULL, max_ks = NULL, alphas = NULL
   bic <- matrix(0, nalpha, nmaxk)
   vars <- list()
   
-  iniset = NULL
-  inihash = NULL
-  maxj = length(max_ks)
+  iniset <- NULL
+  inihash <- NULL
+  maxj <- length(max_ks)
   
-  tic = proc.time()
+  tic <- proc.time()
   
   for (i in 1:nalpha) {
     for (j in 1:nmaxk) {
       
-      results <- MMPC(target, dataset, max_k = max_ks[j], threshold = alphas[i], test, ini = iniset, wei = wei, hash = TRUE, hashObject = inihash, ncores = ncores)
+      results <- MMPC(target, dataset, max_k = max_ks[j], threshold = alphas[i], test = test, ini = iniset, wei = wei, hash = TRUE, hashObject = inihash, ncores = ncores)
       iniset <- results@univ
       inihash <- results@hashObject;
       
@@ -39,9 +39,11 @@ mmpc.path <- function(target, dataset, wei = NULL, max_ks = NULL, alphas = NULL
     }
   }
   
-  runtime = proc.time() - tic
-  rownames(bic) = rownames(size) = paste("alpha=", alphas, sep = "")
-  colnames(bic) = colnames(size) = paste("max_k=", max_ks, sep = "")
+  runtime <- proc.time() - tic
+  rownames(bic) <- paste("alpha=", alphas, sep = "")
+  colnames(bic) <- paste("max_k=", max_ks, sep = "")
+  rownames(size) <- paste("alpha=", alphas, sep = "")
+  colnames(size) <- paste("max_k=", max_ks, sep = "")
   
   list(bic = bic, size = size, variables = vars, runtime = runtime)
   
