@@ -29,9 +29,9 @@ permDcor = function(target, dataset, xIndex, csIndex, wei = NULL, statistic = FA
       xcs = c(xIndex,csIndex2)
       key = paste(as.character(xcs) , collapse=" ");
       
-      if (is.null(stat_hash[[key]]) == FALSE) {
-        stat = stat_hash[[key]];
-        pvalue = pvalue_hash[[key]];
+      if (is.null(stat_hash[key]) == FALSE) {
+        stat = stat_hash[key];
+        pvalue = pvalue_hash[key];
         results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
         return(results);
       }
@@ -39,8 +39,8 @@ permDcor = function(target, dataset, xIndex, csIndex, wei = NULL, statistic = FA
     #if the xIndex is contained in csIndex, x does not bring any new information with respect to cs
     if ( !is.na( match(xIndex, csIndex) ) ) {
       if ( hash ) {        #update hash objects
-        stat_hash[[key]] <- 0;       #.set(stat_hash , key , 0)
-        pvalue_hash[[key]] <- 1;     #.set(pvalue_hash , key , 1)
+        stat_hash[key] <- 0;       #.set(stat_hash , key , 0)
+        pvalue_hash[key] <- 1;     #.set(pvalue_hash , key , 1)
       }
       results <- list(pvalue = 1, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
@@ -62,8 +62,8 @@ permDcor = function(target, dataset, xIndex, csIndex, wei = NULL, statistic = FA
       if ( is.null(dim(cs)[2]) ) {     #cs is a vector
         if ( identical(x, cs) ) {    #if(!any(x == cs) == FALSE)
           if ( hash ) {        #update hash objects
-            stat_hash[[key]] <- 0;         #.set(stat_hash , key , 0)
-            pvalue_hash[[key]] <- 1;        #.set(pvalue_hash , key , 1)
+            stat_hash[key] <- 0;         #.set(stat_hash , key , 0)
+            pvalue_hash[key] <- 1;        #.set(pvalue_hash , key , 1)
           }
           results <- list(pvalue = 1, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
           return(results);
@@ -72,8 +72,8 @@ permDcor = function(target, dataset, xIndex, csIndex, wei = NULL, statistic = FA
         for (col in 1:dim(cs)[2]) {
           if ( identical(x, cs[, col]) )  {    #if(!any(x == cs) == FALSE)
             if ( hash )  {       #update hash objects
-              stat_hash[[key]] <- 0;      #.set(stat_hash , key , 0)
-              pvalue_hash[[key]] <- 1;         #.set(pvalue_hash , key , 1)
+              stat_hash[key] <- 0;      #.set(stat_hash , key , 0)
+              pvalue_hash[key] <- 1;         #.set(pvalue_hash , key , 1)
             }
             results <- list(pvalue = 1, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
             return(results);
@@ -108,8 +108,8 @@ permDcor = function(target, dataset, xIndex, csIndex, wei = NULL, statistic = FA
         } else {
           #update hash objects
           if( hash ) {
-            stat_hash[[key]] <- stat;        #.set(stat_hash , key , stat)
-            pvalue_hash[[key]] <- pvalue;        #.set(pvalue_hash , key , pvalue)
+            stat_hash[key] <- stat;        #.set(stat_hash , key , stat)
+            pvalue_hash[key] <- pvalue;        #.set(pvalue_hash , key , pvalue)
           }
         }
         results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
@@ -149,9 +149,9 @@ permDcor = function(target, dataset, xIndex, csIndex, wei = NULL, statistic = FA
         csIndex2 = sort(csIndex2)
         xcs = c(xIndex, csIndex2)
         key = paste(as.character(xcs) , collapse=" ");
-        if (is.null(stat_hash[[key]]) == FALSE) {
-          stat = stat_hash[[key]];
-          pvalue = pvalue_hash[[key]];
+        if (is.null(stat_hash[key]) == FALSE) {
+          stat = stat_hash[key];
+          pvalue = pvalue_hash[key];
           aa[[ i ]] <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
         }
       }
@@ -160,8 +160,8 @@ permDcor = function(target, dataset, xIndex, csIndex, wei = NULL, statistic = FA
       #information with respect to cs
       if ( !is.na( match(xIndex, csIndex) ) ) { 
         if ( hash ) {    #update hash objects
-          stat_hash[[key]] <- 0;    #.set(stat_hash , key , 0)
-          pvalue_hash[[key]] <- 1;   #.set(pvalue_hash , key , 1)
+          stat_hash[key] <- 0;    #.set(stat_hash , key , 0)
+          pvalue_hash[key] <- 1;   #.set(pvalue_hash , key , 1)
         }
         aa[[ i ]] <- list(pvalue = 1, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       }
@@ -181,8 +181,8 @@ permDcor = function(target, dataset, xIndex, csIndex, wei = NULL, statistic = FA
         if ( is.null( dim(cs )[2]) ) {  #cs is a vector
           if (any(x != cs) == FALSE)  {  #if(!any(x == cs) == FALSE)
             if ( hash )  {  #update hash objects
-              stat_hash[[key]] <- 0;   #.set(stat_hash , key , 0)
-              pvalue_hash[[key]] <- 1;   #.set(pvalue_hash , key , 1)
+              stat_hash[key] <- 0;   #.set(stat_hash , key , 0)
+              pvalue_hash[key] <- 1;   #.set(pvalue_hash , key , 1)
             }
             aa[[ i ]] <- list(pvalue = 1, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
           }
@@ -190,8 +190,8 @@ permDcor = function(target, dataset, xIndex, csIndex, wei = NULL, statistic = FA
           for ( col in 1:ncol(cs) ) {
             if (any(x != cs[, col]) == FALSE) {   #if(!any(x == cs) == FALSE)
               if ( hash ) {    #update hash objects
-                stat_hash[[key]] <- 0;       #.set(stat_hash , key , 0)
-                pvalue_hash[[key]] <- 1;        #.set(pvalue_hash , key , 1)
+                stat_hash[key] <- 0;       #.set(stat_hash , key , 0)
+                pvalue_hash[key] <- 1;        #.set(pvalue_hash , key , 1)
               }
               aa[[ i ]] <- list(pvalue = 1, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
             }
@@ -202,8 +202,8 @@ permDcor = function(target, dataset, xIndex, csIndex, wei = NULL, statistic = FA
       #if x or target is constant then there is no point to perform the test
       if ( Rfast::Var(x)  == 0 ) {
         if ( hash )  {  #update hash objects
-          stat_hash[[key]] <- 0;    #.set(stat_hash , key , 0)
-          pvalue_hash[[key]] <- 1;    #.set(pvalue_hash , key , 1)
+          stat_hash[key] <- 0;    #.set(stat_hash , key , 0)
+          pvalue_hash[key] <- 1;    #.set(pvalue_hash , key , 1)
         }
         aa[[ i ]] <- list(pvalue = 1, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       }
@@ -239,8 +239,8 @@ permDcor = function(target, dataset, xIndex, csIndex, wei = NULL, statistic = FA
           } else {
             
             if( hash ) {
-              stat_hash[[key]] <- stat;    #.set(stat_hash , key , stat)
-              pvalue_hash[[key]] <- pvalue;    #.set(pvalue_hash , key , pvalue)
+              stat_hash[key] <- stat;    #.set(stat_hash , key , stat)
+              pvalue_hash[key] <- pvalue;    #.set(pvalue_hash , key , pvalue)
             }
           }
           #testerrorcaseintrycatch(4);
@@ -264,8 +264,8 @@ permDcor = function(target, dataset, xIndex, csIndex, wei = NULL, statistic = FA
     pvalue = pchisq( stat, 2 * D, lower.tail = FALSE, log.p = TRUE ) 
     
     if ( hash ) {
-      stat_hash[[key]] <- stat
-      pvalue_hash[[key]] <- pvalue  
+      stat_hash[key] <- stat
+      pvalue_hash[key] <- pvalue  
     }
     
     res = list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
