@@ -12,7 +12,6 @@ testIndGLMMOrdinal = function(target, reps = NULL, group, dataset, xIndex, csInd
   #   csIndex: the indices of the variables to condition on. They can be mixed variables, either continous or categorical
   #   this method returns: the pvalue PVALUE, the statistic STAT.
   #cast factor into numeric vector
-  target = as.numeric(as.vector(target));
   csIndex[which(is.na(csIndex))] = 0
   
   if( hash )  {
@@ -20,9 +19,9 @@ testIndGLMMOrdinal = function(target, reps = NULL, group, dataset, xIndex, csInd
     csIndex2 = sort(csIndex2)
     xcs = c(xIndex,csIndex2)
     key = paste(as.character(xcs) , collapse=" ");
-    if( !is.null(stat_hash[[key]]) )  {
-      stat = stat_hash[[key]];
-      pvalue = pvalue_hash[[key]];
+    if( !is.null(stat_hash[key]) )  {
+      stat = stat_hash[key];
+      pvalue = pvalue_hash[key];
       results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
@@ -89,11 +88,11 @@ testIndGLMMOrdinal = function(target, reps = NULL, group, dataset, xIndex, csInd
     } else {
       reps <- reps 
       if ( slopes ) {
-        fit1 = ordinal::clmm( target ~ reps + (reps|group), weights = wei, family = poisson ) 
+        fit1 = ordinal::clmm( target ~ reps + (reps|group), weights = wei ) 
         fit2 = ordinal::clmm( target ~ reps + (reps|group) + x, weights = wei ) 
       } else {
         reps = reps 
-        fit1 = ordinal::clmm( target ~ reps + (1|group), weights = wei, family = poisson )  
+        fit1 = ordinal::clmm( target ~ reps + (1|group), weights = wei )  
         fit2 = ordinal::clmm( target ~ reps + (1|group) + x, weights = wei )  
       }
     }
