@@ -26,9 +26,9 @@ testIndRQ = function(target, dataset, xIndex, csIndex, wei = NULL, univariateMod
     csIndex2 = sort(csIndex2)
     xcs = c(xIndex,csIndex2)
     key = paste(as.character(xcs) , collapse=" ");
-    if(is.null(stat_hash[[key]]) == FALSE)  {
-      stat = stat_hash[[key]];
-      pvalue = pvalue_hash[[key]];
+    if(is.null(stat_hash[key]) == FALSE)  {
+      stat = stat_hash[key];
+      pvalue = pvalue_hash[key];
       results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
@@ -37,8 +37,8 @@ testIndRQ = function(target, dataset, xIndex, csIndex, wei = NULL, univariateMod
   #information with respect to cs
   if ( !is.na( match(xIndex, csIndex) ) )  {
     if( hash )  {       #update hash objects
-      stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
-      pvalue_hash[[key]] <- log(1);#.set(pvalue_hash , key , 1)
+      stat_hash[key] <- 0;#.set(stat_hash , key , 0)
+      pvalue_hash[key] <- log(1);#.set(pvalue_hash , key , 1)
     }
     results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     return(results);
@@ -59,8 +59,8 @@ testIndRQ = function(target, dataset, xIndex, csIndex, wei = NULL, univariateMod
     if ( is.null(dim(cs)[2]) )  {   #cs is a vector
       if ( identical(x, cs) )  {  #if(!any(x == cs) == FALSE)
         if ( hash )  {   #update hash objects
-          stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
-          pvalue_hash[[key]] <- log(1);#.set(pvalue_hash , key , 1)
+          stat_hash[key] <- 0;#.set(stat_hash , key , 0)
+          pvalue_hash[key] <- log(1);#.set(pvalue_hash , key , 1)
         }
         results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
         return(results);
@@ -69,8 +69,8 @@ testIndRQ = function(target, dataset, xIndex, csIndex, wei = NULL, univariateMod
       for (col in 1:dim(cs)[2])  {
         if (identical(x, cs[, col]) )  {    #if(!any(x == cs) == FALSE)
           if ( hash ) {      #update hash objects
-            stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
-            pvalue_hash[[key]] <- log(1);#.set(pvalue_hash , key , 1)
+            stat_hash[key] <- 0;#.set(stat_hash , key , 0)
+            pvalue_hash[key] <- log(1);#.set(pvalue_hash , key , 1)
           }
           results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
           return(results);
@@ -107,8 +107,8 @@ testIndRQ = function(target, dataset, xIndex, csIndex, wei = NULL, univariateMod
   } else {
     #update hash objects
     if ( hash ) {
-      stat_hash[[key]] <- stat;       #.set(stat_hash , key , stat)
-      pvalue_hash[[key]] <- pvalue;       #.set(pvalue_hash , key , pvalue)
+      stat_hash[key] <- stat;       #.set(stat_hash , key , stat)
+      pvalue_hash[key] <- pvalue;       #.set(pvalue_hash , key , pvalue)
     }
   }
   #testerrorcaseintrycatch(4);
