@@ -1,4 +1,4 @@
-tobit.fsreg_2 <- function(target, dataset, iniset = NULL, wei = NULL, threshold = 0.05, tol = 2, heavy, robust = FALSE, ncores = 1) {
+tobit.fsreg_2 <- function(target, dataset, iniset = NULL, wei = NULL, threshold = 0.05, tol = 2, ncores = 1) {
   
   dm <- dim(dataset) 
   if ( is.null(dm) ) {
@@ -23,6 +23,7 @@ tobit.fsreg_2 <- function(target, dataset, iniset = NULL, wei = NULL, threshold
     da <- 1:pa
     dataset <- cbind(iniset, dataset)
   }  
+  dataset <- as.data.frame(dataset)
   
   runtime <- proc.time()
 
